"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createComplexObjectBuilder = void 0;
const PropertyType_1 = require("../../models/property/PropertyType");
const FormBuilder_1 = require("../../components/FormBuilder");
const DynamicArrayField_1 = require("./components/DynamicArrayField");
const react_1 = __importDefault(require("react"));
const ValidationUtil_1 = require("../../utils/common/ValidationUtil");
const createComplexObjectBuilder = (labelRender, validationMessage, loadingSpinner) => {
    const id = "internal_custombuilder";
    const defaultLabelRender = (propertySchema, key) => react_1.default.createElement("label", { key: key }, propertySchema.displayName);
    const defaultValidationMessageElement = (message) => react_1.default.createElement("p", null, message);
    const defaultSpinner = (props, context) => react_1.default.createElement("p", null, "Loading...");
    const builderLabelRender = labelRender !== null && labelRender !== void 0 ? labelRender : defaultLabelRender;
    const builderValidationMessageElement = validationMessage !== null && validationMessage !== void 0 ? validationMessage : defaultValidationMessageElement;
    const loadingSpinnerComponent = () => loadingSpinner !== null && loadingSpinner !== void 0 ? loadingSpinner : defaultSpinner;
    const convertPropertyOverrides = (propertyOverrides, property) => {
        if (propertyOverrides == undefined)
            return undefined;
        let clone = Object.assign({}, propertyOverrides);
        if (Array.isArray(propertyOverrides.disabledProps) && propertyOverrides.disabledProps.indexOf(property) >= 0)
            clone.disabledProps = true;
        return clone;
    };
    const build = (renderProps, property, schema) => {
        var _a;
        let { item, onChange, onBlur, validationResults, validationResultPrefix } = renderProps;
        if (item == null)
            throw Error("item is null");
        if (schema == null)
            throw Error("schema is null");
        let validationIndexer = validationResultPrefix ? `${validationResultPrefix}.${property}` : property;
        let key = `${validationResultPrefix !== null && validationResultPrefix !== void 0 ? validationResultPrefix : ""}${property}`;
        let props = {
            key: (_a = schema.key) !== null && _a !== void 0 ? _a : key,
            value: item[property],
            options: schema,
            onChange: (value) => onChange(property, value),
            onBlur: (value) => onBlur(property, item[property]),
            disabled: schema.disable ? schema.disable(item) : false,
            errorMessage: ValidationUtil_1.validationUtil.getResultAsString(validationResults[validationIndexer]),
            parent: item
        };
        const WrapInLabel = (element, addErrormessage) => {
            return (react_1.default.createElement("div", { className: "formbuilder-property", key: props.key },
                !props.options.hideLabel && builderLabelRender(schema, key + "-label"),
                element,
                (addErrormessage && props.errorMessage) && builderValidationMessageElement(props.errorMessage)));
        };
        const propertyType = PropertyType_1.propertyTypes;
        switch (schema.propertyType) {
            case propertyType.array:
                return { found: true, element: WrapInLabel(react_1.default.createElement(DynamicArrayField_1.DynamicArrayField, Object.assign({}, schema, props))) };
            case propertyType.custom:
                let customConfig = schema.config;
                if (!(customConfig === null || customConfig === void 0 ? void 0 : customConfig.component))
                    return { found: false, element: undefined };
                // const Comp = this.customComponents[customConfig?.componentName];
                const Comp = customConfig.component;
                return { found: true, element: react_1.default.createElement(react_1.default.Fragment, null, WrapInLabel(react_1.default.createElement(Comp, Object.assign({ key: key }, props, schema)))) };
            case propertyType.formItem:
                let formConfig = schema.config;
                if (!(formConfig === null || formConfig === void 0 ? void 0 : formConfig.schemaConfig))
                    return { found: false, element: undefined };
                let formItemProps = {
                    item: item[property],
                    schemaConfig: formConfig.schemaConfig,
                    groupContainer: formConfig.groupContainer,
                    groupRender: formConfig.groupRender,
                    onPropertyChange: (item, prop, value) => props.onChange(item),
                    validationResult: validationResults,
                    validationResultPrefix: property,
                    propertyOverrides: convertPropertyOverrides(renderProps.propertyOverrides, property)
                };
                let addErrormessage = false;
                // used for having properties as array of formitem
                let listProps = schema === null || schema === void 0 ? void 0 : schema.listProps;
                if (listProps != undefined) {
                    formItemProps.onPropertyChange = undefined;
                    listProps.config.onItemsChange = items => props.onChange(items);
                    addErrormessage = true;
                }
                // types sucks sometimes!! (ewi)
                return { found: true, element: react_1.default.createElement(react_1.default.Fragment, null, WrapInLabel(react_1.default.createElement(FormBuilder_1.FormBuilder, Object.assign({ key: key, keyPrefix: key }, formItemProps, formConfig, { listProps: listProps })), addErrormessage)) };
            default: return { found: false, element: undefined };
        }
    };
    return { id, build, loadingSpinnerComponent };
};
exports.createComplexObjectBuilder = createComplexObjectBuilder;
//# sourceMappingURL=ComplexObjectBuilder.js.map