"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFluentBuilder = void 0;
const PropertyType_1 = require("../../models/property/PropertyType");
const DynamicJsonfield_1 = require("./components/dynamicComponents/DynamicJsonfield");
const DynamicBooleanField_1 = require("./components/dynamicComponents/DynamicBooleanField");
const DynamicDateField_1 = require("./components/dynamicComponents/DynamicDateField");
const DynamicPredefinedArrayField_1 = require("./components/dynamicComponents/DynamicPredefinedArrayField");
const DynamicTextfield_1 = require("./components/dynamicComponents/DynamicTextfield");
const react_1 = __importDefault(require("react"));
const FluentPropertyLabel_1 = require("./components/list/components/FluentPropertyLabel");
const FluentFormShimmer_1 = require("./components/list/components/FluentFormShimmer");
const PropertyValidationMark_1 = require("../../utils/common/PropertyValidationMark");
const ValidationUtil_1 = require("../../utils/common/ValidationUtil");
const fluentUiLabel_1 = require("./components/fluentUiLabel");
const FluentList_1 = __importDefault(require("./components/list/FluentList"));
const createFluentBuilder = (labelRender) => {
    const id = "internal_fluentbuilder";
    const defaultLabelRender = fluentUiLabel_1.fluentUiLabel;
    const builderLabelRender = labelRender !== null && labelRender !== void 0 ? labelRender : defaultLabelRender;
    const listComponent = () => FluentList_1.default;
    const loadingSpinnerComponent = () => FluentFormShimmer_1.FluentFormShimmer;
    const build = (renderProps, property, schema) => {
        var _a, _b, _c;
        let { item, onChange, onBlur, validationResults, validationResultPrefix } = renderProps;
        if (item === null)
            throw Error("item is null");
        if (schema == null)
            throw Error("schema is null");
        let validationIndexer = validationResultPrefix ? `${validationResultPrefix}.${property}` : property;
        let key = `prop-${validationResultPrefix !== null && validationResultPrefix !== void 0 ? validationResultPrefix : ""}${property}`;
        let props = {
            key: (_a = schema.key) !== null && _a !== void 0 ? _a : key,
            value: item[property],
            options: schema,
            onChange: (value) => onChange(property, value),
            onBlur: (value) => onBlur(property, value),
            disabled: schema.disable ? schema.disable(item) : false,
            errorMessage: ValidationUtil_1.validationUtil.getResultAsString(validationResults[validationIndexer]),
            parent: item
        };
        let validationMark = (0, PropertyValidationMark_1.getPropertyValidationMark)(((_c = (_b = renderProps === null || renderProps === void 0 ? void 0 : renderProps.schema) === null || _b === void 0 ? void 0 : _b.validation) === null || _c === void 0 ? void 0 : _c.validationRules) && renderProps.schema.validation.validationRules[property]);
        const WrapInLabel = (element) => {
            return (react_1.default.createElement("div", { className: "formbuilder-property", key: `propcon-${key}` },
                react_1.default.createElement(FluentPropertyLabel_1.FluentPropertyLabel, { key: `${key}-labelcontainer`, labelRender: builderLabelRender, propertySchema: schema, hideLabel: props.options.hideLabel, parentKey: key, validationMark: validationMark }),
                element));
        };
        const propertyType = PropertyType_1.propertyTypes;
        switch (schema.propertyType) {
            case propertyType.string: return { found: true, element: WrapInLabel(react_1.default.createElement(DynamicTextfield_1.DynamicTextfield, Object.assign({}, schema, props))) };
            case propertyType.number: return { found: true, element: WrapInLabel(react_1.default.createElement(DynamicTextfield_1.DynamicTextfield, Object.assign({}, schema, props))) };
            case propertyType.boolean: return { found: true, element: WrapInLabel(react_1.default.createElement(DynamicBooleanField_1.DynamicBooleanField, Object.assign({}, schema, props))) };
            case propertyType.date: return { found: true, element: WrapInLabel(react_1.default.createElement(DynamicDateField_1.DynamicDateField, Object.assign({}, schema, props))) };
            case propertyType.json: return { found: true, element: WrapInLabel(react_1.default.createElement(DynamicJsonfield_1.DynamicJsonfield, Object.assign({}, schema, props))) };
            case propertyType.predefinedArray: return { found: true, element: WrapInLabel(react_1.default.createElement(DynamicPredefinedArrayField_1.DynamicPredefinedArrayField, Object.assign({}, schema, props))) };
            default: return { found: false, element: undefined };
        }
    };
    return { id, build, loadingSpinnerComponent, listComponent };
};
exports.createFluentBuilder = createFluentBuilder;
//# sourceMappingURL=FluentBuilder.js.map