import React from 'react';
import { IFormItemOptions } from '../interfaces/options/IFormItemOptions';
import { IFormSchema } from '../interfaces/schema/IFormSchema';
import { ValidationOverride } from '../models/validation/ValidationOverride';
import { ValidationResult } from '../models/validation/ValidationResult';
import { IFormBuilderListConfig, IFormBuilderListSearchConfig, IFormBuilderListColumns, IFormBuilderListMenuConfig, IFormBuilderListEditorConfig } from './config/IFormBuilderListConfig';
import { IFormGrouping } from '../interfaces/IFormGrouping';
import { IPropertyOverrides } from '../interfaces/IPropertyOverrides';
import { ILoadingSpinnerProps } from '../builders/interfaces/ILoadingSpinnerProps';
import { ISchemaProvider } from '../interfaces/schema/ISchemaProvider';
import { RequireOnlyOne } from '..';
import { IFormItem } from '../interfaces/form/IFormItem';
export declare type FormBuilderItemType<T extends IFormItem> = T | Array<T>;
export interface FormBuilderSingleItemProps<T extends IFormItem> {
    onPropertyChange?: (item: T, prop: string, value: any) => void;
}
export interface IFormBuilderListProps<T extends IFormItem> {
    config: IFormBuilderListConfig<T>;
    onItemChange?: (item: T) => void;
    searchConfig?: IFormBuilderListSearchConfig;
    columnConfig?: IFormBuilderListColumns;
    menuConfig?: IFormBuilderListMenuConfig<T>;
    editorConfig?: IFormBuilderListEditorConfig<T>;
}
export interface ISchemaConfig<T extends IFormItem> {
    registeredSchemaKey?: string;
    schemaProvider?: ISchemaProvider<T>;
}
export interface IFormBuilderProps<T extends IFormItem> {
    item: FormBuilderItemType<T>;
    schemaConfig: RequireOnlyOne<ISchemaConfig<T>, "registeredSchemaKey" | "schemaProvider">;
    singleItemProps?: FormBuilderSingleItemProps<T>;
    listProps?: IFormBuilderListProps<T>;
    groupContainer?: React.ElementType<{
        groupings: Array<IFormGrouping>;
    }>;
    groupRender?: (grouping: IFormGrouping, children: Array<any>) => JSX.Element;
    validationOverride?: ValidationOverride;
    formItemConfigOverrides?: Partial<IFormItemOptions<T>>;
    propertyOverrides?: IPropertyOverrides;
    spinnerProps?: ILoadingSpinnerProps;
    keyPrefix?: string;
    overrideSchema?: IFormSchema<T>;
}
export declare type FormBuilderRef<T extends IFormItem> = {
    getItem: () => FormBuilderItemType<T>;
    validateItem: () => Promise<ValidationResult>;
};
export declare const FormBuilder: React.ForwardRefExoticComponent<IFormBuilderProps<IFormItem> & React.RefAttributes<unknown>>;
